<?php
if (!defined('ABSPATH')) die('No direct access allowed');

$GLOBALS['wpo_cache_config'] = json_decode('{"enable_page_caching":true,"page_cache_length_value":24,"page_cache_length_unit":"hours","page_cache_length":86400,"cache_exception_conditional_tags":[""],"cache_exception_urls":[""],"cache_exception_cookies":[""],"cache_exception_browser_agents":[""],"enable_sitemap_preload":false,"enable_schedule_preload":"1","preload_schedule_type":"wpo_use_cache_lifespan","enable_mobile_caching":"0","enable_user_caching":"0","site_url":"https:\/\/antiaginglove.com\/","enable_cache_per_country":false,"permalink_structure":"\/%postname%\/","uploads":"\/home\/antiaginglove\/public_html\/wp-content\/uploads","gmt_offset":"0","enable_per_role_cache":"0","enable_user_specific_cache":"0","enable_browser_cache":"false","browser_cache_expire_days":"28","browser_cache_expire_hours":"0","wpo_cache_cookies":[],"wpo_cache_query_variables":[],"wp_salt_auth":"ukhdvu35zlpjsxgjlwx2x71x87sf3ci4measqzkeoa3f1galxrdr62slxpkzsc6l2ak11wjxfb2uhii4ulso1gjraxl1ywrrf0ttzpssurrgrvknebgtsa65kbjt3bmp","wp_salt_logged_in":"ma47eixdaxsinhofdeo5p4uzqpcdhny9ue5olwhhqh34cohjdfnflyypgko3m5qxh7eobmp3rbf0ybooc7bqvbbj4t1kv4viratyoni0tcmgxtcpj81dscgeqnv3uggu","default_values":[]}', true);
